# Version 1.3.3 (2021-08-20)

* Fixed another crasher with blank lines

# Version 1.3.2 (2021-06-15)

* Fixed crasher with blank lines

# Version 1.3.1 (2021-05-10)

* Fixed crasher introduced in previous version if `--add-noqa` was not passed

# Version 1.3 (2021-04-22)

* Added `--add-noqa` argument

# Version 1.2 (2021-04-15)

* Re-format individual items to have PEP8 whitespace and no line-breaks.

# Version 1.1 (2021-04-06)

* Fixed bug with duplicated comment lines

# Version 1.0 (2021-04-06)

* Re-implemented using libcst, to preserve comments.

# Version 0.0.1 (2021-04-06)

* Initial release
